function [new_x_1, new_x_2, there_are_2_k,...
             is_different_k, is_empty]...
    = all_coordinates_no_preconditioner(k, A, b, x)
% RBK, November 15, 2006 --
%  [new_x_k_1, new_x_k_2, there_are_2,...
%   is_different, is_empty, precond_no]...
%    = all_coordinates_no_preconditioner(k, A, b, x)
% implements applying the interval Gauss--Seidel method for
% each coordinate in each equation, to see the maximum that
% can be obtained without a preconditioner.  Only the
% k-th coordinate is returned, for comparison with other
% coordinate-wise preconditioning techniques.

n = size(A,2);
m = size(A,1);
new_x_1 = x;
new_x_2(1:n) = infsup(Inf,Inf);
there_are_2 = zeros(1,n);
is_different_k = 0;
is_empty = 0;
is_different = zeros(1,n);

for sweep = 1:2
    for coord_no = 1:n;
        Y_k = zeros(1,n);
        Y_k(coord_no) = 1;
        for eq_no = 1:m;
            [new_x_k_s, second_new_x_k_s, there_are_2_s, num, denom] ...
                    = gauss_seidel_step(coord_no, Y_k, A, b, x);
            [xi1, xi2, there_are_2(coord_no),is_empty, is_different_s]...
                   = extended_intersect_with_2 ...
                (new_x_1(coord_no), new_x_2(coord_no), ...
                there_are_2(coord_no),...
                 new_x_k_s, second_new_x_k_s, there_are_2_s);
             if(coord_no == k)
                 there_are_2_k = there_are_2(coord_no);
             end
            is_different(coord_no) = ...
                is_different(coord_no) | is_different_s;
            new_x_1(coord_no) = xi1;
            if(there_are_2(coord_no))
                new_x_2(coord_no) = xi2;
            end
            if(is_empty)
                return
            end
        end
    end
end
is_different_k = is_different(k);



